@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.workflows.executions_v1.services.executions import pagers
 from google.cloud.workflows.executions_v1.types import executions
@@ -102,6 +105,42 @@ class ExecutionsAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ExecutionsClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ExecutionsTransport:
         """Returns the transport used by the client instance.
@@ -177,6 +216,27 @@ class ExecutionsAsyncClient:
         executions are ordered by their start time (newest
         first).
 
+
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1
+
+            def sample_list_executions():
+                # Create a client
+                client = executions_v1.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1.ListExecutionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_executions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.workflows.executions_v1.types.ListExecutionsRequest, dict]):
                 The request object. Request for the
@@ -208,7 +268,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -263,6 +323,26 @@ class ExecutionsAsyncClient:
         r"""Creates a new execution using the latest revision of
         the given workflow.
 
+
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1
+
+            def sample_create_execution():
+                # Create a client
+                client = executions_v1.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1.CreateExecutionRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_execution(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows.executions_v1.types.CreateExecutionRequest, dict]):
                 The request object. Request for the
@@ -297,7 +377,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, execution])
         if request is not None and has_flattened_params:
@@ -346,6 +426,25 @@ class ExecutionsAsyncClient:
     ) -> executions.Execution:
         r"""Returns an execution of the given name.
 
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1
+
+            def sample_get_execution():
+                # Create a client
+                client = executions_v1.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1.GetExecutionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_execution(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows.executions_v1.types.GetExecutionRequest, dict]):
                 The request object. Request for the
@@ -372,7 +471,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -419,6 +518,25 @@ class ExecutionsAsyncClient:
     ) -> executions.Execution:
         r"""Cancels an execution of the given name.
 
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1
+
+            def sample_cancel_execution():
+                # Create a client
+                client = executions_v1.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1.CancelExecutionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.cancel_execution(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows.executions_v1.types.CancelExecutionRequest, dict]):
                 The request object. Request for the
@@ -445,7 +563,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
