@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.workflows.executions_v1beta.services.executions import pagers
 from google.cloud.workflows.executions_v1beta.types import executions
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -101,6 +106,42 @@ class ExecutionsAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ExecutionsClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ExecutionsTransport:
         """Returns the transport used by the client instance.
@@ -163,10 +204,10 @@ class ExecutionsAsyncClient:
 
     async def list_executions(
         self,
-        request: executions.ListExecutionsRequest = None,
+        request: Union[executions.ListExecutionsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListExecutionsAsyncPager:
@@ -176,8 +217,29 @@ class ExecutionsAsyncClient:
         executions are ordered by their start time (newest
         first).
 
+
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1beta
+
+            def sample_list_executions():
+                # Create a client
+                client = executions_v1beta.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1beta.ListExecutionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_executions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest`):
+            request (Union[google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest, dict]):
                 The request object. Request for the
                 [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
                 method.
@@ -207,7 +269,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -251,19 +313,39 @@ class ExecutionsAsyncClient:
 
     async def create_execution(
         self,
-        request: executions.CreateExecutionRequest = None,
+        request: Union[executions.CreateExecutionRequest, dict] = None,
         *,
         parent: str = None,
         execution: executions.Execution = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> executions.Execution:
         r"""Creates a new execution using the latest revision of
         the given workflow.
 
+
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1beta
+
+            def sample_create_execution():
+                # Create a client
+                client = executions_v1beta.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1beta.CreateExecutionRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_execution(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest`):
+            request (Union[google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest, dict]):
                 The request object. Request for the
                 [CreateExecution][google.cloud.workflows.executions.v1beta.Executions.CreateExecution]
                 method.
@@ -296,7 +378,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, execution])
         if request is not None and has_flattened_params:
@@ -336,17 +418,36 @@ class ExecutionsAsyncClient:
 
     async def get_execution(
         self,
-        request: executions.GetExecutionRequest = None,
+        request: Union[executions.GetExecutionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> executions.Execution:
         r"""Returns an execution of the given name.
 
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1beta
+
+            def sample_get_execution():
+                # Create a client
+                client = executions_v1beta.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1beta.GetExecutionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_execution(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows.executions_v1beta.types.GetExecutionRequest`):
+            request (Union[google.cloud.workflows.executions_v1beta.types.GetExecutionRequest, dict]):
                 The request object. Request for the
                 [GetExecution][google.cloud.workflows.executions.v1beta.Executions.GetExecution]
                 method.
@@ -371,7 +472,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -409,17 +510,36 @@ class ExecutionsAsyncClient:
 
     async def cancel_execution(
         self,
-        request: executions.CancelExecutionRequest = None,
+        request: Union[executions.CancelExecutionRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> executions.Execution:
         r"""Cancels an execution of the given name.
 
+        .. code-block::
+
+            from google.cloud.workflows import executions_v1beta
+
+            def sample_cancel_execution():
+                # Create a client
+                client = executions_v1beta.ExecutionsClient()
+
+                # Initialize request argument(s)
+                request = executions_v1beta.CancelExecutionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.cancel_execution(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest`):
+            request (Union[google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest, dict]):
                 The request object. Request for the
                 [CancelExecution][google.cloud.workflows.executions.v1beta.Executions.CancelExecution]
                 method.
@@ -444,7 +564,7 @@ class ExecutionsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
