@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -105,6 +108,42 @@ class WorkflowsAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return WorkflowsClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> WorkflowsTransport:
         """Returns the transport used by the client instance.
@@ -177,6 +216,27 @@ class WorkflowsAsyncClient:
         r"""Lists Workflows in a given project and location.
         The default order is not specified.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1
+
+            def sample_list_workflows():
+                # Create a client
+                client = workflows_v1.WorkflowsClient()
+
+                # Initialize request argument(s)
+                request = workflows_v1.ListWorkflowsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_workflows(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.workflows_v1.types.ListWorkflowsRequest, dict]):
                 The request object. Request for the
@@ -208,7 +268,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -261,6 +321,25 @@ class WorkflowsAsyncClient:
     ) -> workflows.Workflow:
         r"""Gets details of a single Workflow.
 
+        .. code-block::
+
+            from google.cloud import workflows_v1
+
+            def sample_get_workflow():
+                # Create a client
+                client = workflows_v1.WorkflowsClient()
+
+                # Initialize request argument(s)
+                request = workflows_v1.GetWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_workflow(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows_v1.types.GetWorkflowRequest, dict]):
                 The request object. Request for the
@@ -287,7 +366,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -339,6 +418,35 @@ class WorkflowsAsyncClient:
         running operation will return
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1
+
+            def sample_create_workflow():
+                # Create a client
+                client = workflows_v1.WorkflowsClient()
+
+                # Initialize request argument(s)
+                workflow = workflows_v1.Workflow()
+                workflow.source_contents = "source_contents_value"
+
+                request = workflows_v1.CreateWorkflowRequest(
+                    parent="parent_value",
+                    workflow=workflow,
+                    workflow_id="workflow_id_value",
+                )
+
+                # Make the request
+                operation = client.create_workflow(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows_v1.types.CreateWorkflowRequest, dict]):
                 The request object. Request for the
@@ -389,7 +497,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, workflow, workflow_id])
         if request is not None and has_flattened_params:
@@ -450,6 +558,30 @@ class WorkflowsAsyncClient:
         This method also cancels and deletes all running
         executions of the workflow.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1
+
+            def sample_delete_workflow():
+                # Create a client
+                client = workflows_v1.WorkflowsClient()
+
+                # Initialize request argument(s)
+                request = workflows_v1.DeleteWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_workflow(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows_v1.types.DeleteWorkflowRequest, dict]):
                 The request object. Request for the
@@ -489,7 +621,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -550,6 +682,33 @@ class WorkflowsAsyncClient:
         update operation. In that case, such revision will be
         used in new workflow executions.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1
+
+            def sample_update_workflow():
+                # Create a client
+                client = workflows_v1.WorkflowsClient()
+
+                # Initialize request argument(s)
+                workflow = workflows_v1.Workflow()
+                workflow.source_contents = "source_contents_value"
+
+                request = workflows_v1.UpdateWorkflowRequest(
+                    workflow=workflow,
+                )
+
+                # Make the request
+                operation = client.update_workflow(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.workflows_v1.types.UpdateWorkflowRequest, dict]):
                 The request object. Request for the
@@ -584,7 +743,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([workflow, update_mask])
         if request is not None and has_flattened_params:
