@@ -37,6 +37,8 @@ __protobuf__ = proto.module(
 class Workflow(proto.Message):
     r"""Workflow program to be executed by Workflows.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             The resource name of the workflow.
@@ -52,13 +54,16 @@ class Workflow(proto.Message):
         revision_id (str):
             Output only. The revision of the workflow. A new revision of
             a workflow is created as a result of updating the following
-            fields of a workflow:
+            properties of a workflow:
 
-            -  ``source_code``
-            -  ``service_account`` The format is "000001-a4d", where the
-               first 6 characters define the zero-padded revision
-               ordinal number. They are followed by a hyphen and 3
-               hexadecimal random characters.
+            -  [Service
+               account][google.cloud.workflows.v1.Workflow.service_account]
+            -  [Workflow code to be
+               executed][google.cloud.workflows.v1.Workflow.source_contents]
+
+            The format is "000001-a4d", where the first 6 characters
+            define the zero-padded revision ordinal number. They are
+            followed by a hyphen and 3 hexadecimal random characters.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The timestamp of when the
             workflow was created.
@@ -77,23 +82,25 @@ class Workflow(proto.Message):
             must start with a letter. International
             characters are allowed.
         service_account (str):
-            Name of the service account associated with the latest
-            workflow version. This service account represents the
-            identity of the workflow and determines what permissions the
-            workflow has. Format:
-            projects/{project}/serviceAccounts/{account}
+            The service account associated with the latest workflow
+            version. This service account represents the identity of the
+            workflow and determines what permissions the workflow has.
+            Format: projects/{project}/serviceAccounts/{account} or
+            {account}
 
-            Using ``-`` as a wildcard for the ``{project}`` will infer
-            the project from the account. The ``{account}`` value can be
-            the ``email`` address or the ``unique_id`` of the service
-            account.
+            Using ``-`` as a wildcard for the ``{project}`` or not
+            providing one at all will infer the project from the
+            account. The ``{account}`` value can be the ``email``
+            address or the ``unique_id`` of the service account.
 
             If not provided, workflow will use the project's default
             service account. Modifying this field for an existing
             workflow results in a new workflow revision.
         source_contents (str):
             Workflow code to be executed. The size limit
-            is 32KB.
+            is 128KB.
+
+            This field is a member of `oneof`_ ``source_code``.
     """
 
     class State(proto.Enum):
