@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.workflows_v1beta.services.workflows import pagers
@@ -103,6 +108,42 @@ class WorkflowsAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return WorkflowsClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> WorkflowsTransport:
         """Returns the transport used by the client instance.
@@ -165,18 +206,39 @@ class WorkflowsAsyncClient:
 
     async def list_workflows(
         self,
-        request: workflows.ListWorkflowsRequest = None,
+        request: Union[workflows.ListWorkflowsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListWorkflowsAsyncPager:
         r"""Lists Workflows in a given project and location.
         The default order is not specified.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1beta
+
+            def sample_list_workflows():
+                # Create a client
+                client = workflows_v1beta.WorkflowsClient()
+
+                # Initialize request argument(s)
+                request = workflows_v1beta.ListWorkflowsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_workflows(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.workflows_v1beta.types.ListWorkflowsRequest`):
+            request (Union[google.cloud.workflows_v1beta.types.ListWorkflowsRequest, dict]):
                 The request object. Request for the
                 [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
                 method.
@@ -206,7 +268,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -250,17 +312,36 @@ class WorkflowsAsyncClient:
 
     async def get_workflow(
         self,
-        request: workflows.GetWorkflowRequest = None,
+        request: Union[workflows.GetWorkflowRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> workflows.Workflow:
         r"""Gets details of a single Workflow.
 
+        .. code-block::
+
+            from google.cloud import workflows_v1beta
+
+            def sample_get_workflow():
+                # Create a client
+                client = workflows_v1beta.WorkflowsClient()
+
+                # Initialize request argument(s)
+                request = workflows_v1beta.GetWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_workflow(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows_v1beta.types.GetWorkflowRequest`):
+            request (Union[google.cloud.workflows_v1beta.types.GetWorkflowRequest, dict]):
                 The request object. Request for the
                 [GetWorkflow][google.cloud.workflows.v1beta.Workflows.GetWorkflow]
                 method.
@@ -285,7 +366,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -323,12 +404,12 @@ class WorkflowsAsyncClient:
 
     async def create_workflow(
         self,
-        request: workflows.CreateWorkflowRequest = None,
+        request: Union[workflows.CreateWorkflowRequest, dict] = None,
         *,
         parent: str = None,
         workflow: workflows.Workflow = None,
         workflow_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -337,8 +418,37 @@ class WorkflowsAsyncClient:
         running operation will return
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1beta
+
+            def sample_create_workflow():
+                # Create a client
+                client = workflows_v1beta.WorkflowsClient()
+
+                # Initialize request argument(s)
+                workflow = workflows_v1beta.Workflow()
+                workflow.source_contents = "source_contents_value"
+
+                request = workflows_v1beta.CreateWorkflowRequest(
+                    parent="parent_value",
+                    workflow=workflow,
+                    workflow_id="workflow_id_value",
+                )
+
+                # Make the request
+                operation = client.create_workflow(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows_v1beta.types.CreateWorkflowRequest`):
+            request (Union[google.cloud.workflows_v1beta.types.CreateWorkflowRequest, dict]):
                 The request object. Request for the
                 [CreateWorkflow][google.cloud.workflows.v1beta.Workflows.CreateWorkflow]
                 method.
@@ -387,7 +497,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, workflow, workflow_id])
         if request is not None and has_flattened_params:
@@ -437,10 +547,10 @@ class WorkflowsAsyncClient:
 
     async def delete_workflow(
         self,
-        request: workflows.DeleteWorkflowRequest = None,
+        request: Union[workflows.DeleteWorkflowRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -448,8 +558,32 @@ class WorkflowsAsyncClient:
         This method also cancels and deletes all running
         executions of the workflow.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1beta
+
+            def sample_delete_workflow():
+                # Create a client
+                client = workflows_v1beta.WorkflowsClient()
+
+                # Initialize request argument(s)
+                request = workflows_v1beta.DeleteWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_workflow(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows_v1beta.types.DeleteWorkflowRequest`):
+            request (Union[google.cloud.workflows_v1beta.types.DeleteWorkflowRequest, dict]):
                 The request object. Request for the
                 [DeleteWorkflow][google.cloud.workflows.v1beta.Workflows.DeleteWorkflow]
                 method.
@@ -487,7 +621,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -533,11 +667,11 @@ class WorkflowsAsyncClient:
 
     async def update_workflow(
         self,
-        request: workflows.UpdateWorkflowRequest = None,
+        request: Union[workflows.UpdateWorkflowRequest, dict] = None,
         *,
         workflow: workflows.Workflow = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -548,8 +682,35 @@ class WorkflowsAsyncClient:
         update operation. In that case, such revision will be
         used in new workflow executions.
 
+
+        .. code-block::
+
+            from google.cloud import workflows_v1beta
+
+            def sample_update_workflow():
+                # Create a client
+                client = workflows_v1beta.WorkflowsClient()
+
+                # Initialize request argument(s)
+                workflow = workflows_v1beta.Workflow()
+                workflow.source_contents = "source_contents_value"
+
+                request = workflows_v1beta.UpdateWorkflowRequest(
+                    workflow=workflow,
+                )
+
+                # Make the request
+                operation = client.update_workflow(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.workflows_v1beta.types.UpdateWorkflowRequest`):
+            request (Union[google.cloud.workflows_v1beta.types.UpdateWorkflowRequest, dict]):
                 The request object. Request for the
                 [UpdateWorkflow][google.cloud.workflows.v1beta.Workflows.UpdateWorkflow]
                 method.
@@ -582,7 +743,7 @@ class WorkflowsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([workflow, update_mask])
         if request is not None and has_flattened_params:
