@@ -29,6 +29,7 @@ from google.api_core import future
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
+from google.api_core import operation
 from google.api_core import operation_async  # type: ignore
 from google.api_core import operations_v1
 from google.api_core import path_template
@@ -239,20 +240,20 @@ def test_workflows_client_client_options(client_class, transport_class, transpor
     # unsupported value.
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "Unsupported"}):
         with pytest.raises(MutualTLSChannelError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case GOOGLE_API_USE_CLIENT_CERTIFICATE has unsupported value.
     with mock.patch.dict(
         os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "Unsupported"}
     ):
         with pytest.raises(ValueError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case quota_project_id is provided
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -309,7 +310,7 @@ def test_workflows_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(transport=transport_name, client_options=options)
+            client = client_class(client_options=options, transport=transport_name)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -386,6 +387,83 @@ def test_workflows_client_mtls_env_auto(
                 )
 
 
+@pytest.mark.parametrize("client_class", [WorkflowsClient, WorkflowsAsyncClient])
+@mock.patch.object(
+    WorkflowsClient, "DEFAULT_ENDPOINT", modify_default_endpoint(WorkflowsClient)
+)
+@mock.patch.object(
+    WorkflowsAsyncClient,
+    "DEFAULT_ENDPOINT",
+    modify_default_endpoint(WorkflowsAsyncClient),
+)
+def test_workflows_client_get_mtls_endpoint_and_cert_source(client_class):
+    mock_client_cert_source = mock.Mock()
+
+    # Test the case GOOGLE_API_USE_CLIENT_CERTIFICATE is "true".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        mock_api_endpoint = "foo"
+        options = client_options.ClientOptions(
+            client_cert_source=mock_client_cert_source, api_endpoint=mock_api_endpoint
+        )
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source(
+            options
+        )
+        assert api_endpoint == mock_api_endpoint
+        assert cert_source == mock_client_cert_source
+
+    # Test the case GOOGLE_API_USE_CLIENT_CERTIFICATE is "false".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "false"}):
+        mock_client_cert_source = mock.Mock()
+        mock_api_endpoint = "foo"
+        options = client_options.ClientOptions(
+            client_cert_source=mock_client_cert_source, api_endpoint=mock_api_endpoint
+        )
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source(
+            options
+        )
+        assert api_endpoint == mock_api_endpoint
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "never".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "never"}):
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+        assert api_endpoint == client_class.DEFAULT_ENDPOINT
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "always".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "always"}):
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+        assert api_endpoint == client_class.DEFAULT_MTLS_ENDPOINT
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "auto" and default cert doesn't exist.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        with mock.patch(
+            "google.auth.transport.mtls.has_default_client_cert_source",
+            return_value=False,
+        ):
+            api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+            assert api_endpoint == client_class.DEFAULT_ENDPOINT
+            assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "auto" and default cert exists.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        with mock.patch(
+            "google.auth.transport.mtls.has_default_client_cert_source",
+            return_value=True,
+        ):
+            with mock.patch(
+                "google.auth.transport.mtls.default_client_cert_source",
+                return_value=mock_client_cert_source,
+            ):
+                (
+                    api_endpoint,
+                    cert_source,
+                ) = client_class.get_mtls_endpoint_and_cert_source()
+                assert api_endpoint == client_class.DEFAULT_MTLS_ENDPOINT
+                assert cert_source == mock_client_cert_source
+
+
 @pytest.mark.parametrize(
     "client_class,transport_class,transport_name",
     [
@@ -404,7 +482,7 @@ def test_workflows_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -418,24 +496,26 @@ def test_workflows_client_client_options_scopes(
 
 
 @pytest.mark.parametrize(
-    "client_class,transport_class,transport_name",
+    "client_class,transport_class,transport_name,grpc_helpers",
     [
-        (WorkflowsClient, transports.WorkflowsGrpcTransport, "grpc"),
+        (WorkflowsClient, transports.WorkflowsGrpcTransport, "grpc", grpc_helpers),
         (
             WorkflowsAsyncClient,
             transports.WorkflowsGrpcAsyncIOTransport,
             "grpc_asyncio",
+            grpc_helpers_async,
         ),
     ],
 )
 def test_workflows_client_client_options_credentials_file(
-    client_class, transport_class, transport_name
+    client_class, transport_class, transport_name, grpc_helpers
 ):
     # Check the case credentials file is provided.
     options = client_options.ClientOptions(credentials_file="credentials.json")
+
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -466,9 +546,69 @@ def test_workflows_client_client_options_from_dict():
         )
 
 
-def test_list_workflows(
-    transport: str = "grpc", request_type=workflows.ListWorkflowsRequest
+@pytest.mark.parametrize(
+    "client_class,transport_class,transport_name,grpc_helpers",
+    [
+        (WorkflowsClient, transports.WorkflowsGrpcTransport, "grpc", grpc_helpers),
+        (
+            WorkflowsAsyncClient,
+            transports.WorkflowsGrpcAsyncIOTransport,
+            "grpc_asyncio",
+            grpc_helpers_async,
+        ),
+    ],
+)
+def test_workflows_client_create_channel_credentials_file(
+    client_class, transport_class, transport_name, grpc_helpers
 ):
+    # Check the case credentials file is provided.
+    options = client_options.ClientOptions(credentials_file="credentials.json")
+
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file="credentials.json",
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+        )
+
+    # test that the credentials from file are saved and used as the credentials.
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel"
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        file_creds = ga_credentials.AnonymousCredentials()
+        load_creds.return_value = (file_creds, None)
+        adc.return_value = (creds, None)
+        client = client_class(client_options=options, transport=transport_name)
+        create_channel.assert_called_with(
+            "workflows.googleapis.com:443",
+            credentials=file_creds,
+            credentials_file=None,
+            quota_project_id=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=None,
+            default_host="workflows.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize("request_type", [workflows.ListWorkflowsRequest, dict,])
+def test_list_workflows(request_type, transport: str = "grpc"):
     client = WorkflowsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -496,10 +636,6 @@ def test_list_workflows(
     assert response.unreachable == ["unreachable_value"]
 
 
-def test_list_workflows_from_dict():
-    test_list_workflows(request_type=dict)
-
-
 def test_list_workflows_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -620,7 +756,9 @@ def test_list_workflows_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
 
 
 def test_list_workflows_flattened_error():
@@ -654,7 +792,9 @@ async def test_list_workflows_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -669,8 +809,10 @@ async def test_list_workflows_flattened_error_async():
         )
 
 
-def test_list_workflows_pager():
-    client = WorkflowsClient(credentials=ga_credentials.AnonymousCredentials,)
+def test_list_workflows_pager(transport_name: str = "grpc"):
+    client = WorkflowsClient(
+        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_workflows), "__call__") as call:
@@ -707,8 +849,10 @@ def test_list_workflows_pager():
         assert all(isinstance(i, workflows.Workflow) for i in results)
 
 
-def test_list_workflows_pages():
-    client = WorkflowsClient(credentials=ga_credentials.AnonymousCredentials,)
+def test_list_workflows_pages(transport_name: str = "grpc"):
+    client = WorkflowsClient(
+        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_workflows), "__call__") as call:
@@ -807,9 +951,8 @@ async def test_list_workflows_async_pages():
             assert page_.raw_page.next_page_token == token
 
 
-def test_get_workflow(
-    transport: str = "grpc", request_type=workflows.GetWorkflowRequest
-):
+@pytest.mark.parametrize("request_type", [workflows.GetWorkflowRequest, dict,])
+def test_get_workflow(request_type, transport: str = "grpc"):
     client = WorkflowsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -845,10 +988,6 @@ def test_get_workflow(
     assert response.service_account == "service_account_value"
 
 
-def test_get_workflow_from_dict():
-    test_get_workflow(request_type=dict)
-
-
 def test_get_workflow_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -973,7 +1112,9 @@ def test_get_workflow_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 def test_get_workflow_flattened_error():
@@ -1005,7 +1146,9 @@ async def test_get_workflow_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1020,9 +1163,8 @@ async def test_get_workflow_flattened_error_async():
         )
 
 
-def test_create_workflow(
-    transport: str = "grpc", request_type=workflows.CreateWorkflowRequest
-):
+@pytest.mark.parametrize("request_type", [workflows.CreateWorkflowRequest, dict,])
+def test_create_workflow(request_type, transport: str = "grpc"):
     client = WorkflowsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1046,10 +1188,6 @@ def test_create_workflow(
     assert isinstance(response, future.Future)
 
 
-def test_create_workflow_from_dict():
-    test_create_workflow(request_type=dict)
-
-
 def test_create_workflow_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1169,9 +1307,15 @@ def test_create_workflow_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
-        assert args[0].workflow == workflows.Workflow(name="name_value")
-        assert args[0].workflow_id == "workflow_id_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
+        arg = args[0].workflow
+        mock_val = workflows.Workflow(name="name_value")
+        assert arg == mock_val
+        arg = args[0].workflow_id
+        mock_val = "workflow_id_value"
+        assert arg == mock_val
 
 
 def test_create_workflow_flattened_error():
@@ -1212,9 +1356,15 @@ async def test_create_workflow_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
-        assert args[0].workflow == workflows.Workflow(name="name_value")
-        assert args[0].workflow_id == "workflow_id_value"
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
+        arg = args[0].workflow
+        mock_val = workflows.Workflow(name="name_value")
+        assert arg == mock_val
+        arg = args[0].workflow_id
+        mock_val = "workflow_id_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1232,9 +1382,8 @@ async def test_create_workflow_flattened_error_async():
         )
 
 
-def test_delete_workflow(
-    transport: str = "grpc", request_type=workflows.DeleteWorkflowRequest
-):
+@pytest.mark.parametrize("request_type", [workflows.DeleteWorkflowRequest, dict,])
+def test_delete_workflow(request_type, transport: str = "grpc"):
     client = WorkflowsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1258,10 +1407,6 @@ def test_delete_workflow(
     assert isinstance(response, future.Future)
 
 
-def test_delete_workflow_from_dict():
-    test_delete_workflow(request_type=dict)
-
-
 def test_delete_workflow_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1377,7 +1522,9 @@ def test_delete_workflow_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 def test_delete_workflow_flattened_error():
@@ -1411,7 +1558,9 @@ async def test_delete_workflow_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1426,9 +1575,8 @@ async def test_delete_workflow_flattened_error_async():
         )
 
 
-def test_update_workflow(
-    transport: str = "grpc", request_type=workflows.UpdateWorkflowRequest
-):
+@pytest.mark.parametrize("request_type", [workflows.UpdateWorkflowRequest, dict,])
+def test_update_workflow(request_type, transport: str = "grpc"):
     client = WorkflowsClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1452,10 +1600,6 @@ def test_update_workflow(
     assert isinstance(response, future.Future)
 
 
-def test_update_workflow_from_dict():
-    test_update_workflow(request_type=dict)
-
-
 def test_update_workflow_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1578,8 +1722,12 @@ def test_update_workflow_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].workflow == workflows.Workflow(name="name_value")
-        assert args[0].update_mask == field_mask_pb2.FieldMask(paths=["paths_value"])
+        arg = args[0].workflow
+        mock_val = workflows.Workflow(name="name_value")
+        assert arg == mock_val
+        arg = args[0].update_mask
+        mock_val = field_mask_pb2.FieldMask(paths=["paths_value"])
+        assert arg == mock_val
 
 
 def test_update_workflow_flattened_error():
@@ -1618,8 +1766,12 @@ async def test_update_workflow_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].workflow == workflows.Workflow(name="name_value")
-        assert args[0].update_mask == field_mask_pb2.FieldMask(paths=["paths_value"])
+        arg = args[0].workflow
+        mock_val = workflows.Workflow(name="name_value")
+        assert arg == mock_val
+        arg = args[0].update_mask
+        mock_val = field_mask_pb2.FieldMask(paths=["paths_value"])
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1656,6 +1808,23 @@ def test_credentials_transport_error():
             transport=transport,
         )
 
+    # It is an error to provide an api_key and a transport instance.
+    transport = transports.WorkflowsGrpcTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    options = client_options.ClientOptions()
+    options.api_key = "api_key"
+    with pytest.raises(ValueError):
+        client = WorkflowsClient(client_options=options, transport=transport,)
+
+    # It is an error to provide an api_key and a credential.
+    options = mock.Mock()
+    options.api_key = "api_key"
+    with pytest.raises(ValueError):
+        client = WorkflowsClient(
+            client_options=options, credentials=ga_credentials.AnonymousCredentials()
+        )
+
     # It is an error to provide scopes and a transport instance.
     transport = transports.WorkflowsGrpcTransport(
         credentials=ga_credentials.AnonymousCredentials(),
@@ -2168,7 +2337,7 @@ def test_parse_common_location_path():
     assert expected == actual
 
 
-def test_client_withDEFAULT_CLIENT_INFO():
+def test_client_with_default_client_info():
     client_info = gapic_v1.client_info.ClientInfo()
 
     with mock.patch.object(
@@ -2233,3 +2402,33 @@ def test_client_ctx():
             with client:
                 pass
             close.assert_called()
+
+
+@pytest.mark.parametrize(
+    "client_class,transport_class",
+    [
+        (WorkflowsClient, transports.WorkflowsGrpcTransport),
+        (WorkflowsAsyncClient, transports.WorkflowsGrpcAsyncIOTransport),
+    ],
+)
+def test_api_key_credentials(client_class, transport_class):
+    with mock.patch.object(
+        google.auth._default, "get_api_key_credentials", create=True
+    ) as get_api_key_credentials:
+        mock_cred = mock.Mock()
+        get_api_key_credentials.return_value = mock_cred
+        options = client_options.ClientOptions()
+        options.api_key = "api_key"
+        with mock.patch.object(transport_class, "__init__") as patched:
+            patched.return_value = None
+            client = client_class(client_options=options)
+            patched.assert_called_once_with(
+                credentials=mock_cred,
+                credentials_file=None,
+                host=client.DEFAULT_ENDPOINT,
+                scopes=None,
+                client_cert_source_for_mtls=None,
+                quota_project_id=None,
+                client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
+            )
